===============================
ParcelBrigh API wrapper
===============================

.. image:: https://img.shields.io/travis/onjin/parcelbright-python.svg
        :target: https://travis-ci.org/onjin/parcelbright-python

.. image:: https://img.shields.io/pypi/v/parcelbright.svg
        :target: https://pypi.python.org/pypi/parcelbright


ParcelBright API wrapper. For full ParcelBright API reference go to https://github.com/parcelbright/api-docs

* Free software: BSD license
* Documentation: https://parcelbright-python.readthedocs.org.

Features
--------

* create new shipment to get rates from
* find previously created shipment
* book shipment
* get tracking data
* cancel shipment

TODO
----

* Customs support
* Carriers liability support
